<link rel="stylesheet" href="//vjs.zencdn.net/7.8.2/video-js.min.css" rel="stylesheet">
<!-- <script crossorigin src="https://unpkg.com/react@17/umd/react.development.js"></script> -->
<!-- <script crossorigin src="https://unpkg.com/react-dom@17/umd/react-dom.development.js"></script> -->
<script crossorigin src="https://cdn.jsdelivr.net/gh/josedvq/covfee@master/covfee/static/js/opencv.js"></script>
<script src="//vjs.zencdn.net/7.8.2/video.min.js"></script>